@@ -1,4 +1,4 @@
-# Copyright (C) 2014 Red Hat
+# Copyright Red Hat
 #
 # This file is part of python-wikitcms.
 #
@@ -273,7 +273,7 @@ class ValidationPage(Page):
         if len(rows) > 1 and env:
             # the way this match is done must be kept in line with the
             # corresponding match in add_results, below
-            rows = [r for r in rows if nrml(env) in [renv.lower() for renv in r.results.keys()]]
+            rows = [r for r in rows if nrml(env) in [nrml(renv) for renv in r.results.keys()]]
         # try a more precise name match - e.g. "upgrade_dnf" vs.
         # "upgrade_dnf_encrypted"
         if len(rows) > 1:
