@@ -1,4 +1,4 @@
-# Copyright (C) 2016 Red Hat
+# Copyright Red Hat
 #
 # This file is part of python-wikitcms.
 #
@@ -148,26 +148,6 @@ class TestEventFedfind:
         with pytest.raises(FedfindNotFoundError):
             assert event.ff_release_images
 
-    @mock.patch("fedfind.release.ModularCompose.exists", True)
-    @mock.patch("fedfind.release.ModularCompose.all_images", ["foo"])
-    def test_candidate_ff_release_modular(self):
-        """Straightforward ff_release test case for a modular
-        candidate compose which is properly synced to stage.
-        """
-        event = wikitcms.event.ComposeEvent(
-            self.site,
-            "27",
-            "Beta",
-            "1.5",
-            dist="Fedora-Modular",
-            cid="Fedora-Modular-27-20171108.2",
-        )
-        assert isinstance(event.ff_release, fedfind.release.ModularCompose)
-        assert isinstance(event.ff_release_images, fedfind.release.ModularCompose)
-        event = wikitcms.event.ComposeEvent(self.site, "27", "Beta", "1.5", dist="Fedora-Modular")
-        assert isinstance(event.ff_release, fedfind.release.ModularCompose)
-        assert isinstance(event.ff_release_images, fedfind.release.ModularCompose)
-
     @mock.patch("fedfind.release.IoTNightly.exists", True)
     @mock.patch("fedfind.release.IoTNightly.all_images", ["foo"])
     def test_candidate_ff_release_iot(self):
