@@ -1,6 +1,6 @@
 # -*- coding: utf-8 -*-
 
-# Copyright (C) 2016 Red Hat
+# Copyright Red Hat
 #
 # This file is part of python-wikitcms.
 #
@@ -706,7 +706,11 @@ The explanation of test case priority is available at [[QA:Fedora_12_Install_Tes
             name="Podman",
         )
         self._check_resultrow(
-            rows[5], "QA:Testcase_base_selinux", "Basic", cols, {"x86_64": 1, "aarch64": 1},
+            rows[5],
+            "QA:Testcase_base_selinux",
+            "Basic",
+            cols,
+            {"x86_64": 1, "aarch64": 1},
         )
         self._check_resultrow(
             rows[6],
